@@ -88,10 +88,12 @@ pub fn assign_codes(root: &Box<Node>,
 
         None => {
             if let Some(ref l) = root.left
-            { bitvec.push(false); assign_codes(l, hashmap, bitvec); }
+            { bitvec.push(false);
+              assign_codes(l, hashmap, bitvec); }
 
             if let Some(ref r) = root.right
-            { bitvec.push(true); assign_codes(r, hashmap, bitvec); }
+            { bitvec.push(true);
+              assign_codes(r, hashmap, bitvec); }
         }
     }
     bitvec.pop();
@@ -135,7 +137,7 @@ pub fn huffman_encode(s: &str, char_codes: &mut HashMap<char, BitVec>) -> BitVec
 }
 
 fn decode_string(bitvec: &BitVec, root: &Box<Node>) -> String {
-    let mut res:     String     = "".to_string();
+    let mut res:     String     = String::new();
     let mut nodeptr: &Box<Node> = root;
 
     for b in bitvec {
